﻿using System;
using System.Net;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace WebServiceClientCS
{
    /// <summary>
    /// Sample class that demonstrates calling a Web service
    /// with a custom HTTP header.
    /// </summary>
    class WebServicesMathClient
    {
        [STAThread]
        static void Main(string[] args)
        {
            // Get x,y from the console
            Console.Write("X:");
            int x = int.Parse(Console.ReadLine());
            Console.Write("Y:");
            int y = int.Parse(Console.ReadLine());

            // Instantiate the derived math service
            MyMathService mathService = new MyMathService();

            // Call the add method and print the result
            float result = mathService.Add(x, y);
            Console.WriteLine(x + " + " + y + " = " + result);
        }
    }

    /// <summary>
    /// MyMathService gets a WebRequest and sets the default credentials
    /// and a custom header on the request.  If you need control over the
    /// HTTP semantics of a Web service request it is much better to override
    /// the auto generated proxy class so that you don't lose the changes when
    /// the proxy gets re-generated.
    /// </summary>
    class MyMathService : WebServiceClientCS.localhost.Service1
    {
        // GetWebRequest is called before the SOAP request is sent
        protected override WebRequest GetWebRequest(Uri url)
        {
            // Create a request based on the supplied URI
            WebRequest request = WebRequest.Create(url);

            // Set default credentials		
            request.Credentials = CredentialCache.DefaultCredentials;

            // Set a custom header value on the request
            request.Headers["custom-header"] = "custom-value";

            return request;
        }
    }
}
